@@ -1,10 +1,10 @@
 // isqrt().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_low.h"
+#include "base/cl_low.h"
 
 
 // Implementation.
@@ -61,7 +61,6 @@ uintL isqrt (uintL x)
      }}
 }
 
-#ifdef HAVE_LONGLONG
 uintL isqrt (uintQ x)
 {
   // As isqrt (uintL) above, but with 64-bit numbers.
@@ -94,6 +93,5 @@ uintL isqrt (uintQ x)
          }
      }}
 }
-#endif
 
 }  // namespace cln
