@@ -1,7 +1,7 @@
 // binary operator *
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/ffloat.h"
@@ -9,17 +9,15 @@
 
 // Implementation.
 
-#include "cl_FF.h"
-#include "cl_F.h"
-#include "cl_low.h"
-#include "cl_ieee.h"
+#include "float/ffloat/cl_FF.h"
+#include "float/cl_F.h"
+#include "base/cl_low.h"
 
-#include "cl_inline.h"
-#include "cl_FF_zerop.cc"
+#include "base/cl_inline.h"
+#include "float/ffloat/elem/cl_FF_zerop.cc"
 
 namespace cln {
 
-NEED_IEEE_FLOATS()
 
 const cl_FF operator* (const cl_FF& x1, const cl_FF& x2)
 {
