@@ -1,7 +1,7 @@
 // deriv().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/univpoly.h"
