@@ -1,16 +1,18 @@
 // binary operator /
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
-#include "cl_RA.h"
-#include "cl_integer.h"
+#include "rational/cl_RA.h"
+#include "cln/integer.h"
+
+namespace cln {
 
 const cl_RA operator/ (const cl_RA& r, const cl_RA& s)
 {
@@ -24,3 +26,5 @@ const cl_RA operator/ (const cl_RA& r, const cl_RA& s)
 	}
 	return r * recip(s);
 }
+
+}  // namespace cln
