@@ -1,7 +1,7 @@
 // copy().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #define CL_GV_NO_RANGECHECKS
@@ -14,9 +14,9 @@ namespace cln {
 
 const cl_GV_number copy (const cl_GV_number& v)
 {
-	var uintC len = v.length();
-	var cl_GV_number w = cl_GV_number(len);
-	cl_GV_number::copy_elements(v,0,w,0,len);
+	std::size_t len = v.size();
+	cl_GV_number w = cl_GV_number(len);
+	cl_GV_number::copy_elements(v, 0, w, 0, len);
 	return w;
 }
 
