@@ -1,7 +1,7 @@
 // copy().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #define CL_SV_NO_RANGECHECKS
@@ -16,12 +16,12 @@ namespace cln {
 
 const cl_SV_any copy (const cl_SV_any& src)
 {
-	var uintC len = src.length();
-	var cl_heap_SV_any* hv = (cl_heap_SV_any*) malloc_hook(sizeof(cl_heap_SV_any)+sizeof(cl_gcobject)*len);
+	std::size_t len = src.size();
+	cl_heap_SV_any* hv = (cl_heap_SV_any*) malloc_hook(sizeof(cl_heap_SV_any)+sizeof(cl_gcobject)*len);
 	hv->refcount = 1;
 	hv->type = src.pointer_type();
 	new (&hv->v) cl_SV_inner<cl_gcobject> (len);
-	for (var uintC i = 0; i < len; i++)
+	for (std::size_t i = 0; i < len; i++)
 		init1(cl_gcobject, hv->v[i]) (src[i]);
 	return hv;
 }
