@@ -2,13 +2,16 @@
 #include <cln/io.h>
 #include <cln/integer.h>
 #include <cln/lfloat.h>
-#include "cl_LF.h"
+#include "float/lfloat/cl_LF.h"
 #include <cln/rational.h>
 #include <cln/float_io.h>
 #include <cln/random.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
+#include <iostream>
+using namespace cln;
+using namespace std;
 
 int main (int argc, char * argv[])
 {
